=======
History
=======

0.1.0 (2020-05-09)
------------------

* First release on PyPI.


0.2.0 (2020-08-20)
------------------

* Add method get_feature_of_interest()
* Add example for accessing and plotting sensor data

0.3.0 (2020-08-30)
------------------

* Add method get_data()
* Add method get_sites()
* Add method sosFeaturesOfInterest()
* Update example notebook for accessing and plotting sensor data
